@@ -62,6 +62,8 @@
 #' - [panel_tail()] - Used to generate tails for multiple time series groups.
 #'
 #' @examples
+#'
+#' \donttest{
 #' # Libraries & Setup ----
 #' library(modeltime)
 #' library(tidymodels)
@@ -200,6 +202,7 @@
 #'         .conf_interval_show = FALSE
 #'     )
 #'
+#' }
 #'
 #' @export
 recursive <- function(object, transform, train_tail, id = NULL, ...){
@@ -649,13 +652,13 @@ panel_tail <- function(data, id, n){
                 dplyr::select(-!!.derived_features)
 
             recipes::bake(.recipe, new_data = temp_new_data) %>%
-                dplyr::slice_tail(n = new_data_size) %>%
+                dplyr::slice_tail(n = as.integer(new_data_size)) %>%
                 .[slice_idx, ]
         }
     } else if (inherits(.transform, "function")){
         .transform_fun <- function(temp_new_data, new_data_size, slice_idx){
             .transform(temp_new_data) %>%
-                dplyr::slice_tail(n = new_data_size) %>%
+                dplyr::slice_tail(n = as.integer(new_data_size)) %>%
                 .[slice_idx, ]
         }
     }
@@ -683,7 +686,7 @@ panel_tail <- function(data, id, n){
                 dplyr::group_split() %>%
                 purrr::map(function(x){
 
-                    dplyr::slice_tail(x, n = new_data_size) %>%
+                    dplyr::slice_tail(x, n = as.integer(round(new_data_size))) %>%
                         .[slice_idx, ]
 
                 }) %>%
